#!/bin/bash
#
# build-client.sh
#
# Copyright (C) 2011 Cesnet z.s.p.o
# Author(s):    Tomas PLESNIK   <plesnik@ics.muni.cz>
#               Jan SOUKAL      <soukal@ics.muni.cz>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the Cesnet z.s.p.o nor the names of its
#    contributors may be used to endorse or promote products derived from
#     this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall the Cesnet z.s.p.o or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.

VERSION="1.0.0"

err()
{
  echo "FAILED!"
  cat $err
  rm -rf $err
  rm -rf $package
  rm -rf $tar
  rm -rf $sig
  echo
  echo "Build of $package FAILED!!!"
  exit 1
}


#-------------------------------------------------------------------------------
#				MAIN
#-------------------------------------------------------------------------------

# edit when you build new package
version="1.0.1"

package="warden-client-$version"
doc="$package/warden-client/doc"
etc="$package/warden-client/etc"
lib="$package/warden-client/lib"
var="$package/warden-client/var"
tar="$package.tar.gz"
sig="$tar.sig"
err="/tmp/build-client-err"

# make directory structure
echo "Building warden client package version $version ..."
echo

echo -n "Building 'base' directory ... "
mkdir -p $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/warden-client/sh/* $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/warden-client/doc/CHANGELOG $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/warden-client/doc/INSTALL $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/warden-client/doc/LICENSE $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/warden-client/doc/README $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$doc' directory ... "
mkdir -p $doc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/warden-client/doc/* $doc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$etc' directory ... "
mkdir -p $etc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$lib' directory ... "
mkdir -p $lib 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/warden-client/lib/* $lib 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$var' directory ... "
mkdir -p $var 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


# tar package
echo -n "Making $tar package ... "
tar czf $tar $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


# make sign
echo -n "Making $sig file ... "
sha1sum $tar > $sig 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo
echo "Building of $package was SUCCESSFULL"

# cleanup section
rm -rf $package

exit 0
